@@ -19,6 +19,12 @@ our %EXPORT_TAGS = ( 'all' => [ qw(
             count_quadruplets
             count_quintuplets
             count_sextuplets
+            print_primes
+            print_twins
+            print_triplets
+            print_quadruplets
+            print_quintuplets
+            print_sextuplets
             get_num_threads
             get_max_stop
             get_sieve_size
@@ -31,7 +37,7 @@ our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 
 our @EXPORT = @EXPORT_OK;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 sub AUTOLOAD {
     # This AUTOLOAD is used to 'autoload' constants from the constant()
@@ -126,6 +132,31 @@ Counts quintuplets primes within the given range.
 
 Counts sextuplets primes within the given range.
 
+
+=item $num = print_primes ($start, $stop)
+
+Print primes within the given range to stdout.
+
+=item $num = print_twins ($start, $stop)
+
+Print twin primes within the given range to stdout.
+
+=item $num = print_triplets ($start, $stop)
+
+Print triple primes within the given range to stdout.
+
+=item $num = print_quadruplets ($start, $stop)
+
+Print quadruplets primes within the given range to stdout.
+
+=item $num = print_quintuplets ($start, $stop)
+
+Print quintuplets primes within the given range to stdout.
+
+=item $num = print_sextuplets ($start, $stop)
+
+Print sextuplets primes within the given range to stdout.
+
 =item $num = get_max_stop ()
 
 Returns the largest valid stop number for primesieve.
